PyXMake Developer Guide: PyXMake.VTL.docker Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Functions | Variables
PyXMake.VTL.docker Namespace Reference

## Functions
| main (directory=False, feature=False)

## Variables
| parser = argparse.ArgumentParser(description="Set up Docker in WSL2 on the current machine. Requires administrator privileges if Windows containers are desired.")
| metavar
| nargs
| help
| _ = sys.argv[1]
| args
| directory = os.path.expanduser("~");
| feature = "linux" ;

## Detailed Description

    Minimum working example for PyXMake.

    @note: Install Docker on any machine.
    Created on 29.10.2021

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          - PyXMake

    @change:
          -

    @author: garb_ma                                      [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ main()

PyXMake.VTL.docker.main | ( |  | directory = False,
|  |  | feature = False )

    Main function to execute the script.
    Installs Docker on the current machine (Windows)

Definition at line 36 of file docker.py.

## Variable Documentation

## ◆ _

PyXMake.VTL.docker._ = sys.argv[1]
| protected

Definition at line 67 of file docker.py.

## ◆ args

PyXMake.VTL.docker.args

Definition at line 68 of file docker.py.

## ◆ directory

PyXMake.VTL.docker.directory = os.path.expanduser("~");

Definition at line 70 of file docker.py.

## ◆ feature

str PyXMake.VTL.docker.feature = "linux" ;

Definition at line 73 of file docker.py.

## ◆ help

PyXMake.VTL.docker.help

Definition at line 63 of file docker.py.

## ◆ metavar

PyXMake.VTL.docker.metavar

Definition at line 63 of file docker.py.

## ◆ nargs

PyXMake.VTL.docker.nargs

Definition at line 63 of file docker.py.

## ◆ parser

PyXMake.VTL.docker.parser = argparse.ArgumentParser(description="Set up Docker in WSL2 on the current machine. Requires administrator privileges if Windows containers are desired.")

Definition at line 62 of file docker.py.